"""Django X-Robots-Tag Middleware"""

from django.conf import settings
import logging

logger = logging.getLogger(__name__)


class XRobotsTagMiddleware(object):
    """Adds X-Robots-Tag Based on Settings"""

    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        logger.debug("x_robots_tag_middleware")
        response = self.get_response(request)

        if settings.X_ROBOTS_TAG:
            response["X-Robots-Tag"] = ",".join(settings.X_ROBOTS_TAG)
            logger.debug(f"x_robots_tag: {settings.X_ROBOTS_TAG}")

        return response



from setuptools import setup, find_packages
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name="django-x-robots-tag-middleware",
    version="1.3.3",
    url="https://github.com/cyface/django-x-robots-tag-middleware",
    license="MIT",
    description="Enables returning the X-Robots-Tag header based on Django settings.",
    long_description=long_description,
    long_description_content_type='text/markdown',
    author="Tim White",
    author_email="tim@cyface.com",
    packages=find_packages(
        exclude=("x_robots_tag_middleware_demo", "tests", "devscripts")
    ),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        "django>=1.10",
    ],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Internet :: WWW/HTTP",
    ],
)



from django.test import TestCase, override_settings
import logging

logger = logging.getLogger(__name__)


class XRobotsMiddlewareTests(TestCase):
    """Tests Terms and Conditions Module"""

    def test_middleware(self):
        """
        Validate that a middleware sets X-Robots-Tag
        Depends on settings and setup in the _demo project
        """

        logger.debug("Test Middleware")
        response = self.client.get("/")
        self.assertIn("x-robots-tag", response._headers)
        self.assertEqual(
            response._headers.get("x-robots-tag", ""),
            ("X-Robots-Tag", "noindex,nofollow"),
        )

    @override_settings(X_ROBOTS_TAG=None)
    def test_middleware_no_setting(self):
        """
        Validate that a middleware sets X-Robots-Tag
        Depends on settings and setup in the _demo project
        """

        logger.debug("Test Middleware No Setting")
        response = self.client.get("/")
        self.assertNotIn("x-robots-tag", response._headers)
        self.assertContains(response, "This is the test page!")
